==> ficus-0.2.0157.tgz: ficus/pages/scaffold/ViewScaffoldForeperson.php <==
<?php 
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
/*
 * Copyright 2004-2007 Project Guarana Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * @package ficus.pages.scaffold
 */
/**
 * @file ViewScaffoldForeperson.php
 * @brief table manager page
 * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
 * @version $Id: ViewScaffoldForeperson.php 2 2007-07-11 10:37:48Z ishitoya $
 */

require_once("ficus/pages/AbstractPage.php");
require_once("ficus/config/Registry.php");
require_once("ficus/db/s2dao/models/serializer/S2DaoS2DaoArrayEntityDeserializer.php");
require_once("common/AbstractPage.php");

/**
 * @class Ficus_ViewScaffoldForeperson
 */
class Ficus_ViewScaffoldForeperson extends Ficus_AbstractScaffold
    /**
     * view
     * @param $args array of arguments
     */
    public function doDefault($args){
        $entity = $this->getSingleEntity($this->extractArgument($args, "id"));
        if(is_null($entity) == false){
            $container = $this->getContainer($entity);
            
            $organizer = $this->getViewOrganizer();
            $organizer->setItemTemplate("row");
            $organizer->setEntityTemplate("table");
            
            $container->addOrganizers($organizer);
            $this->assignReference("container", $container);
        }
        
        return self::MODE_TEMPLATE;
    }
}    
?>

==> ficus-0.2.0161.tgz: ficus/pages/scaffold/ViewScaffoldForeperson.php <==
<?php 
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
/*
 * Copyright 2004-2007 Project Guarana Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * @package ficus.pages.scaffold
 */
/**
 * @file ViewScaffoldForeperson.php
 * @brief table manager page
 * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
 * @version $Id: ViewScaffoldForeperson.php 14 2007-07-18 14:55:12Z ishitoya $
 */

require_once("ficus/pages/AbstractPage.php");
require_once("ficus/config/Registry.php");
require_once("common/AbstractPage.php");

/**
 * @class Ficus_ViewScaffoldForeperson
 */
class Ficus_ViewScaffoldForeperson extends Ficus_AbstractScaffoldForeperson{
    /**
     * view
     * @param $args array of arguments
     */
    public function doDefault(){
        $id = $this->mediator->request()->extractAsInt(self::KEY_ID);
        $entity = $this->mediator->daoManager()->getSingleEntity($id);
        $container = $this->mediator->getContainer($entity);
        
        $organizer =
            $this->mediator->organizerFactory()->createViewOrganizer();
        
        $organizer->setItemTemplate("row");
        $organizer->setEntityTemplate("table");
        
        $container->addOrganizers($organizer);

        return $container->build();
    }
}    
?>
